# Discord Emoji processing
## Requirements
`discordemoji` requires a python version greater than `3.6`, but no additional requirements in order to be run.
## Basic Usage
You can directly install the package using 